@@ -890,9 +890,16 @@ def runner_input(
         name, s_value = buf
 
         # find corresponding input declaration
-        try:
-            decl = available_inputs[name]
-        except KeyError:
+        decl = available_inputs.get(name)
+
+        if not decl:
+            # allow arbitrary runtime overrides
+            nmparts = name.split(".")
+            runtime_idx = next((i for i, term in enumerate(nmparts) if term in ("runtime",)), -1)
+            if runtime_idx >= 0 and len(nmparts) > (runtime_idx + 1):
+                decl = available_inputs.get(".".join(nmparts[:runtime_idx] + ["_runtime"]))
+
+        if not decl:
             runner_input_help(target)
             raise Error.InputError(f"No such input to {target.name}: {buf[0]}")
 
@@ -900,10 +907,7 @@ def runner_input(
         v = runner_input_value(s_value, decl.type, downloadable, root)
 
         # insert value into input_env
-        try:
-            existing = input_env[name]
-        except KeyError:
-            existing = None
+        existing = input_env.get(name)
         if existing:
             if isinstance(v, Value.Array):
                 assert isinstance(existing, Value.Array) and v.type.coerces(existing.type)
@@ -986,6 +990,7 @@ def runner_input_help(target):
         ans.append(bold(f"  {str(b.value.type)} {b.name}"))
         add_wrapped_parameter_meta(target, b.name, ans)
     optional_inputs = target.available_inputs.subtract(target.required_inputs)
+    optional_inputs = optional_inputs.filter(lambda b: not b.value.name.startswith("_"))
     if target.inputs is None:
         # if the target doesn't have an input{} section (pre WDL 1.0), exclude
         # declarations bound to a non-constant expression (heuristic)
@@ -1067,6 +1072,17 @@ def runner_input_value(s_value, ty, downloadable, root):
         return Value.Array(
             ty.item_type, [runner_input_value(s_value, ty.item_type, downloadable, root)]
         )
+    if isinstance(ty, Type.Any):
+        # infer dynamically-typed runtime overrides
+        try:
+            return Value.Int(int(s_value))
+        except ValueError:
+            pass
+        try:
+            return Value.Float(float(s_value))
+        except ValueError:
+            pass
+        return Value.String(s_value)
     raise Error.InputError(
         "No command-line support yet for inputs of type {}; workaround: specify in JSON file with --input".format(
             str(ty)
@@ -1504,6 +1520,10 @@ def fill_configure_subparser(subparsers):
 
 
 def configure(cfg=None, show=False, force=False, **kwargs):
+    if not (sys.stdin.isatty() and sys.stdout.isatty()):
+        die("`miniwdl configure` is for interactive use")
+
+    from datetime import datetime
     import bullet
     from xdg import XDG_CONFIG_HOME
 
@@ -1521,19 +1541,21 @@ def configure(cfg=None, show=False, force=False, **kwargs):
         if not cfg:
             cfg = os.path.join(XDG_CONFIG_HOME, "miniwdl.cfg")
 
+        def yes(prompt):
+            return bullet.Bullet(prompt=prompt, choices=["No", "Yes"]).launch() == "Yes"
+
         if os.path.exists(cfg):
             assert force
-            logger.warn("Deleting existing configuration file at " + cfg)
+            logger.warn("Proceeding will overwrite existing configuration file at " + cfg)
+            sys.stderr.flush()
+            if not yes("OVERWRITE?"):
+                sys.exit(0)
             os.unlink(cfg)
         logger.notice("Generating configuration file at " + cfg)
         sys.stderr.flush()
 
         options = {}
         try:
-
-            def yes(prompt):
-                return bullet.Bullet(prompt=prompt, choices=["No", "Yes"]).launch() == "Yes"
-
             print(
                 textwrap.dedent(
                     """
@@ -1600,13 +1622,18 @@ def configure(cfg=None, show=False, force=False, **kwargs):
         print(cfg_content)
         print()
         sys.stdout.flush()
+        os.makedirs(os.path.dirname(cfg), exist_ok=True)
         with open(cfg, "w") as outfile:
+            print(
+                f"# miniwdl configure {miniwdl_version or '(version unknown)'} {datetime.utcnow()}Z",
+                file=outfile,
+            )
             print(cfg_content, file=outfile)
         logger.notice("Wrote configuration file " + cfg)
         logger.notice("Edit the file manually to set advanced options available: ")
         logger.notice(
             "    https://github.com/chanzuckerberg/miniwdl/blob/"
-            f"{miniwdl_version}/WDL/runtime/config_templates/default.cfg"
+            f"{miniwdl_version or 'main'}/WDL/runtime/config_templates/default.cfg"
         )
         logger.notice(
             "Runtime environment variables may override configuration file options; see documentation:"
