@@ -1,5 +1,5 @@
 # pyre-strict
-from typing import List, Optional, NamedTuple, Union, Iterable, TypeVar, Generator, Callable, Any
+from typing import List, Optional, Union, Iterable, TypeVar, Generator, Callable, Any
 from functools import total_ordering
 from contextlib import contextmanager
 
